# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetSksNodepoolListResult',
    'AwaitableGetSksNodepoolListResult',
    'get_sks_nodepool_list',
    'get_sks_nodepool_list_output',
]

@pulumi.output_type
class GetSksNodepoolListResult:
    """
    A collection of values returned by getSksNodepoolList.
    """
    def __init__(__self__, cluster_id=None, created_at=None, deploy_target_id=None, description=None, disk_size=None, id=None, instance_pool_id=None, instance_prefix=None, instance_type=None, ipv6=None, labels=None, name=None, nodepools=None, size=None, state=None, storage_lvm=None, taints=None, template_id=None, version=None, zone=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if deploy_target_id and not isinstance(deploy_target_id, str):
            raise TypeError("Expected argument 'deploy_target_id' to be a str")
        pulumi.set(__self__, "deploy_target_id", deploy_target_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if disk_size and not isinstance(disk_size, int):
            raise TypeError("Expected argument 'disk_size' to be a int")
        pulumi.set(__self__, "disk_size", disk_size)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_pool_id and not isinstance(instance_pool_id, str):
            raise TypeError("Expected argument 'instance_pool_id' to be a str")
        pulumi.set(__self__, "instance_pool_id", instance_pool_id)
        if instance_prefix and not isinstance(instance_prefix, str):
            raise TypeError("Expected argument 'instance_prefix' to be a str")
        pulumi.set(__self__, "instance_prefix", instance_prefix)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if ipv6 and not isinstance(ipv6, bool):
            raise TypeError("Expected argument 'ipv6' to be a bool")
        pulumi.set(__self__, "ipv6", ipv6)
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        pulumi.set(__self__, "labels", labels)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if nodepools and not isinstance(nodepools, list):
            raise TypeError("Expected argument 'nodepools' to be a list")
        pulumi.set(__self__, "nodepools", nodepools)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if storage_lvm and not isinstance(storage_lvm, bool):
            raise TypeError("Expected argument 'storage_lvm' to be a bool")
        pulumi.set(__self__, "storage_lvm", storage_lvm)
        if taints and not isinstance(taints, dict):
            raise TypeError("Expected argument 'taints' to be a dict")
        pulumi.set(__self__, "taints", taints)
        if template_id and not isinstance(template_id, str):
            raise TypeError("Expected argument 'template_id' to be a str")
        pulumi.set(__self__, "template_id", template_id)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="deployTargetId")
    def deploy_target_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "deploy_target_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[_builtins.int]:
        """
        Match against this int
        """
        return pulumi.get(self, "disk_size")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instancePoolId")
    def instance_pool_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "instance_pool_id")

    @_builtins.property
    @pulumi.getter(name="instancePrefix")
    def instance_prefix(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "instance_prefix")

    @_builtins.property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "instance_type")

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> Optional[_builtins.bool]:
        """
        Match against this bool
        """
        return pulumi.get(self, "ipv6")

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
        """
        return pulumi.get(self, "labels")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def nodepools(self) -> Sequence['outputs.GetSksNodepoolListNodepoolResult']:
        return pulumi.get(self, "nodepools")

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[_builtins.int]:
        """
        Match against this int
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="storageLvm")
    def storage_lvm(self) -> Optional[_builtins.bool]:
        """
        Match against this bool
        """
        return pulumi.get(self, "storage_lvm")

    @_builtins.property
    @pulumi.getter
    def taints(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
        """
        return pulumi.get(self, "taints")

    @_builtins.property
    @pulumi.getter(name="templateId")
    def template_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "template_id")

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        """
        The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")


class AwaitableGetSksNodepoolListResult(GetSksNodepoolListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSksNodepoolListResult(
            cluster_id=self.cluster_id,
            created_at=self.created_at,
            deploy_target_id=self.deploy_target_id,
            description=self.description,
            disk_size=self.disk_size,
            id=self.id,
            instance_pool_id=self.instance_pool_id,
            instance_prefix=self.instance_prefix,
            instance_type=self.instance_type,
            ipv6=self.ipv6,
            labels=self.labels,
            name=self.name,
            nodepools=self.nodepools,
            size=self.size,
            state=self.state,
            storage_lvm=self.storage_lvm,
            taints=self.taints,
            template_id=self.template_id,
            version=self.version,
            zone=self.zone)


def get_sks_nodepool_list(cluster_id: Optional[_builtins.str] = None,
                          created_at: Optional[_builtins.str] = None,
                          deploy_target_id: Optional[_builtins.str] = None,
                          description: Optional[_builtins.str] = None,
                          disk_size: Optional[_builtins.int] = None,
                          id: Optional[_builtins.str] = None,
                          instance_pool_id: Optional[_builtins.str] = None,
                          instance_prefix: Optional[_builtins.str] = None,
                          instance_type: Optional[_builtins.str] = None,
                          ipv6: Optional[_builtins.bool] = None,
                          labels: Optional[Mapping[str, _builtins.str]] = None,
                          name: Optional[_builtins.str] = None,
                          size: Optional[_builtins.int] = None,
                          state: Optional[_builtins.str] = None,
                          storage_lvm: Optional[_builtins.bool] = None,
                          taints: Optional[Mapping[str, _builtins.str]] = None,
                          template_id: Optional[_builtins.str] = None,
                          version: Optional[_builtins.str] = None,
                          zone: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSksNodepoolListResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str cluster_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str created_at: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str deploy_target_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str description: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int disk_size: Match against this int
    :param _builtins.str id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_pool_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_prefix: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool ipv6: Match against this bool
    :param Mapping[str, _builtins.str] labels: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str name: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int size: Match against this int
    :param _builtins.str state: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool storage_lvm: Match against this bool
    :param Mapping[str, _builtins.str] taints: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str template_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str version: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str zone: The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['createdAt'] = created_at
    __args__['deployTargetId'] = deploy_target_id
    __args__['description'] = description
    __args__['diskSize'] = disk_size
    __args__['id'] = id
    __args__['instancePoolId'] = instance_pool_id
    __args__['instancePrefix'] = instance_prefix
    __args__['instanceType'] = instance_type
    __args__['ipv6'] = ipv6
    __args__['labels'] = labels
    __args__['name'] = name
    __args__['size'] = size
    __args__['state'] = state
    __args__['storageLvm'] = storage_lvm
    __args__['taints'] = taints
    __args__['templateId'] = template_id
    __args__['version'] = version
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('exoscale:index/getSksNodepoolList:getSksNodepoolList', __args__, opts=opts, typ=GetSksNodepoolListResult).value

    return AwaitableGetSksNodepoolListResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        deploy_target_id=pulumi.get(__ret__, 'deploy_target_id'),
        description=pulumi.get(__ret__, 'description'),
        disk_size=pulumi.get(__ret__, 'disk_size'),
        id=pulumi.get(__ret__, 'id'),
        instance_pool_id=pulumi.get(__ret__, 'instance_pool_id'),
        instance_prefix=pulumi.get(__ret__, 'instance_prefix'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        ipv6=pulumi.get(__ret__, 'ipv6'),
        labels=pulumi.get(__ret__, 'labels'),
        name=pulumi.get(__ret__, 'name'),
        nodepools=pulumi.get(__ret__, 'nodepools'),
        size=pulumi.get(__ret__, 'size'),
        state=pulumi.get(__ret__, 'state'),
        storage_lvm=pulumi.get(__ret__, 'storage_lvm'),
        taints=pulumi.get(__ret__, 'taints'),
        template_id=pulumi.get(__ret__, 'template_id'),
        version=pulumi.get(__ret__, 'version'),
        zone=pulumi.get(__ret__, 'zone'))
def get_sks_nodepool_list_output(cluster_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 created_at: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 deploy_target_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 disk_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                 id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 instance_pool_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 instance_prefix: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 instance_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 ipv6: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                 labels: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                 name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                 state: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 storage_lvm: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                 taints: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                 template_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 version: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSksNodepoolListResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str cluster_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str created_at: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str deploy_target_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str description: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int disk_size: Match against this int
    :param _builtins.str id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_pool_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_prefix: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str instance_type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool ipv6: Match against this bool
    :param Mapping[str, _builtins.str] labels: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str name: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int size: Match against this int
    :param _builtins.str state: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool storage_lvm: Match against this bool
    :param Mapping[str, _builtins.str] taints: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str template_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str version: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str zone: The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['createdAt'] = created_at
    __args__['deployTargetId'] = deploy_target_id
    __args__['description'] = description
    __args__['diskSize'] = disk_size
    __args__['id'] = id
    __args__['instancePoolId'] = instance_pool_id
    __args__['instancePrefix'] = instance_prefix
    __args__['instanceType'] = instance_type
    __args__['ipv6'] = ipv6
    __args__['labels'] = labels
    __args__['name'] = name
    __args__['size'] = size
    __args__['state'] = state
    __args__['storageLvm'] = storage_lvm
    __args__['taints'] = taints
    __args__['templateId'] = template_id
    __args__['version'] = version
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('exoscale:index/getSksNodepoolList:getSksNodepoolList', __args__, opts=opts, typ=GetSksNodepoolListResult)
    return __ret__.apply(lambda __response__: GetSksNodepoolListResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        deploy_target_id=pulumi.get(__response__, 'deploy_target_id'),
        description=pulumi.get(__response__, 'description'),
        disk_size=pulumi.get(__response__, 'disk_size'),
        id=pulumi.get(__response__, 'id'),
        instance_pool_id=pulumi.get(__response__, 'instance_pool_id'),
        instance_prefix=pulumi.get(__response__, 'instance_prefix'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        ipv6=pulumi.get(__response__, 'ipv6'),
        labels=pulumi.get(__response__, 'labels'),
        name=pulumi.get(__response__, 'name'),
        nodepools=pulumi.get(__response__, 'nodepools'),
        size=pulumi.get(__response__, 'size'),
        state=pulumi.get(__response__, 'state'),
        storage_lvm=pulumi.get(__response__, 'storage_lvm'),
        taints=pulumi.get(__response__, 'taints'),
        template_id=pulumi.get(__response__, 'template_id'),
        version=pulumi.get(__response__, 'version'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[_builtins.str] name: ❗ The DNS domain name.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The DNS domain name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
                 expires_on: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[_builtins.bool] auto_renew: Whether the DNS domain has automatic renewal enabled (boolean).
        :param pulumi.Input[_builtins.str] expires_on: The domain expiration date, if known.
        :param pulumi.Input[_builtins.str] name: ❗ The DNS domain name.
        :param pulumi.Input[_builtins.str] state: The domain state.
        :param pulumi.Input[_builtins.str] token: A security token that can be used as an alternative way to manage DNS domains via the Exoscale API.
        """
        if auto_renew is not None:
            warnings.warn("""Not used, will be removed in the future""", DeprecationWarning)
            pulumi.log.warn("""auto_renew is deprecated: Not used, will be removed in the future""")
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if expires_on is not None:
            warnings.warn("""Not used, will be removed in the future""", DeprecationWarning)
            pulumi.log.warn("""expires_on is deprecated: Not used, will be removed in the future""")
        if expires_on is not None:
            pulumi.set(__self__, "expires_on", expires_on)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if state is not None:
            warnings.warn("""Not used, will be removed in the future""", DeprecationWarning)
            pulumi.log.warn("""state is deprecated: Not used, will be removed in the future""")
        if state is not None:
            pulumi.set(__self__, "state", state)
        if token is not None:
            warnings.warn("""Not used, will be removed in the future""", DeprecationWarning)
            pulumi.log.warn("""token is deprecated: Not used, will be removed in the future""")
        if token is not None:
            pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter(name="autoRenew")
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def auto_renew(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the DNS domain has automatic renewal enabled (boolean).
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @_builtins.property
    @pulumi.getter(name="expiresOn")
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def expires_on(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain expiration date, if known.
        """
        return pulumi.get(self, "expires_on")

    @expires_on.setter
    def expires_on(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_on", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The DNS domain name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A security token that can be used as an alternative way to manage DNS domains via the Exoscale API.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)


@pulumi.type_token("exoscale:index/domain:Domain")
class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manage Exoscale [DNS](https://community.exoscale.com/product/networking/dns/) Domains.

        Corresponding data source: exoscale_domain.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_domain = exoscale.Domain("my_domain", name="my.domain")
        ```

        Next step is to attach exoscale_domain_record(s) to the domain.

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing DNS domain may be imported by `ID`:

        ```sh
        $ pulumi import exoscale:index/domain:Domain \\ 
        ```

          exoscale_domain.my_domain \\

          89083a5c-b648-474a-0000-0000000f67bd

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: ❗ The DNS domain name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DomainArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage Exoscale [DNS](https://community.exoscale.com/product/networking/dns/) Domains.

        Corresponding data source: exoscale_domain.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_domain = exoscale.Domain("my_domain", name="my.domain")
        ```

        Next step is to attach exoscale_domain_record(s) to the domain.

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing DNS domain may be imported by `ID`:

        ```sh
        $ pulumi import exoscale:index/domain:Domain \\ 
        ```

          exoscale_domain.my_domain \\

          89083a5c-b648-474a-0000-0000000f67bd

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["auto_renew"] = None
            __props__.__dict__["expires_on"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["token"] = None
        super(Domain, __self__).__init__(
            'exoscale:index/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
            expires_on: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] auto_renew: Whether the DNS domain has automatic renewal enabled (boolean).
        :param pulumi.Input[_builtins.str] expires_on: The domain expiration date, if known.
        :param pulumi.Input[_builtins.str] name: ❗ The DNS domain name.
        :param pulumi.Input[_builtins.str] state: The domain state.
        :param pulumi.Input[_builtins.str] token: A security token that can be used as an alternative way to manage DNS domains via the Exoscale API.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["expires_on"] = expires_on
        __props__.__dict__["name"] = name
        __props__.__dict__["state"] = state
        __props__.__dict__["token"] = token
        return Domain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="autoRenew")
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def auto_renew(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the DNS domain has automatic renewal enabled (boolean).
        """
        return pulumi.get(self, "auto_renew")

    @_builtins.property
    @pulumi.getter(name="expiresOn")
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def expires_on(self) -> pulumi.Output[_builtins.str]:
        """
        The domain expiration date, if known.
        """
        return pulumi.get(self, "expires_on")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The DNS domain name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        The domain state.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Not used, will be removed in the future""")
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        A security token that can be used as an alternative way to manage DNS domains via the Exoscale API.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DbaasPgDatabaseArgs', 'DbaasPgDatabase']

@pulumi.input_type
class DbaasPgDatabaseArgs:
    def __init__(__self__, *,
                 database_name: pulumi.Input[_builtins.str],
                 service: pulumi.Input[_builtins.str],
                 zone: pulumi.Input[_builtins.str],
                 lc_collate: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_ctype: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a DbaasPgDatabase resource.
        :param pulumi.Input[_builtins.str] database_name: ❗ The name of the database for this service.
        :param pulumi.Input[_builtins.str] service: ❗ The name of the database service.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        :param pulumi.Input[_builtins.str] lc_collate: Default string sort order (LC_COLLATE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] lc_ctype: Default character classification (LC_CTYPE) for PostgreSQL database
        """
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "service", service)
        pulumi.set(__self__, "zone", zone)
        if lc_collate is not None:
            pulumi.set(__self__, "lc_collate", lc_collate)
        if lc_ctype is not None:
            pulumi.set(__self__, "lc_ctype", lc_ctype)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Input[_builtins.str]:
        """
        ❗ The name of the database for this service.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "database_name", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> pulumi.Input[_builtins.str]:
        """
        ❗ The name of the database service.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Input[_builtins.str]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "zone", value)

    @_builtins.property
    @pulumi.getter(name="lcCollate")
    def lc_collate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default string sort order (LC_COLLATE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_collate")

    @lc_collate.setter
    def lc_collate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lc_collate", value)

    @_builtins.property
    @pulumi.getter(name="lcCtype")
    def lc_ctype(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default character classification (LC_CTYPE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_ctype")

    @lc_ctype.setter
    def lc_ctype(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lc_ctype", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _DbaasPgDatabaseState:
    def __init__(__self__, *,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_collate: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_ctype: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DbaasPgDatabase resources.
        :param pulumi.Input[_builtins.str] database_name: ❗ The name of the database for this service.
        :param pulumi.Input[_builtins.str] lc_collate: Default string sort order (LC_COLLATE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] lc_ctype: Default character classification (LC_CTYPE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] service: ❗ The name of the database service.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if lc_collate is not None:
            pulumi.set(__self__, "lc_collate", lc_collate)
        if lc_ctype is not None:
            pulumi.set(__self__, "lc_ctype", lc_ctype)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The name of the database for this service.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_name", value)

    @_builtins.property
    @pulumi.getter(name="lcCollate")
    def lc_collate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default string sort order (LC_COLLATE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_collate")

    @lc_collate.setter
    def lc_collate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lc_collate", value)

    @_builtins.property
    @pulumi.getter(name="lcCtype")
    def lc_ctype(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default character classification (LC_CTYPE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_ctype")

    @lc_ctype.setter
    def lc_ctype(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lc_ctype", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The name of the database service.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['DbaasPgDatabaseTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("exoscale:index/dbaasPgDatabase:DbaasPgDatabase")
class DbaasPgDatabase(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_collate: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_ctype: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['DbaasPgDatabaseTimeoutsArgs', 'DbaasPgDatabaseTimeoutsArgsDict']]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ❗ Manage service database for a PostgreSQL Exoscale [Database Services (DBaaS)](https://community.exoscale.com/documentation/dbaas/).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] database_name: ❗ The name of the database for this service.
        :param pulumi.Input[_builtins.str] lc_collate: Default string sort order (LC_COLLATE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] lc_ctype: Default character classification (LC_CTYPE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] service: ❗ The name of the database service.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbaasPgDatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ❗ Manage service database for a PostgreSQL Exoscale [Database Services (DBaaS)](https://community.exoscale.com/documentation/dbaas/).

        :param str resource_name: The name of the resource.
        :param DbaasPgDatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbaasPgDatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_collate: Optional[pulumi.Input[_builtins.str]] = None,
                 lc_ctype: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['DbaasPgDatabaseTimeoutsArgs', 'DbaasPgDatabaseTimeoutsArgsDict']]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbaasPgDatabaseArgs.__new__(DbaasPgDatabaseArgs)

            if database_name is None and not opts.urn:
                raise TypeError("Missing required property 'database_name'")
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["lc_collate"] = lc_collate
            __props__.__dict__["lc_ctype"] = lc_ctype
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__.__dict__["service"] = service
            __props__.__dict__["timeouts"] = timeouts
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
        super(DbaasPgDatabase, __self__).__init__(
            'exoscale:index/dbaasPgDatabase:DbaasPgDatabase',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            database_name: Optional[pulumi.Input[_builtins.str]] = None,
            lc_collate: Optional[pulumi.Input[_builtins.str]] = None,
            lc_ctype: Optional[pulumi.Input[_builtins.str]] = None,
            service: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['DbaasPgDatabaseTimeoutsArgs', 'DbaasPgDatabaseTimeoutsArgsDict']]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'DbaasPgDatabase':
        """
        Get an existing DbaasPgDatabase resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] database_name: ❗ The name of the database for this service.
        :param pulumi.Input[_builtins.str] lc_collate: Default string sort order (LC_COLLATE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] lc_ctype: Default character classification (LC_CTYPE) for PostgreSQL database
        :param pulumi.Input[_builtins.str] service: ❗ The name of the database service.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbaasPgDatabaseState.__new__(_DbaasPgDatabaseState)

        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["lc_collate"] = lc_collate
        __props__.__dict__["lc_ctype"] = lc_ctype
        __props__.__dict__["service"] = service
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["zone"] = zone
        return DbaasPgDatabase(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The name of the database for this service.
        """
        return pulumi.get(self, "database_name")

    @_builtins.property
    @pulumi.getter(name="lcCollate")
    def lc_collate(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default string sort order (LC_COLLATE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_collate")

    @_builtins.property
    @pulumi.getter(name="lcCtype")
    def lc_ctype(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default character classification (LC_CTYPE) for PostgreSQL database
        """
        return pulumi.get(self, "lc_ctype")

    @_builtins.property
    @pulumi.getter
    def service(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The name of the database service.
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.DbaasPgDatabaseTimeouts']]:
        return pulumi.get(self, "timeouts")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDomainResult',
    'AwaitableGetDomainResult',
    'get_domain',
    'get_domain_output',
]

@pulumi.output_type
class GetDomainResult:
    """
    A collection of values returned by getDomain.
    """
    def __init__(__self__, id=None, name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The DNS domain name to match.
        """
        return pulumi.get(self, "name")


class AwaitableGetDomainResult(GetDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainResult(
            id=self.id,
            name=self.name)


def get_domain(name: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainResult:
    """
    Fetch Exoscale [DNS](https://community.exoscale.com/product/networking/dns/) Domains data.

    Corresponding resource: exoscale_domain.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_exoscale as exoscale

    my_domain = exoscale.get_domain(name="my.domain")
    pulumi.export("myDomainId", my_domain.id)
    ```

    Please refer to the examples
    directory for complete configuration examples.


    :param _builtins.str name: The DNS domain name to match.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('exoscale:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult).value

    return AwaitableGetDomainResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_domain_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainResult]:
    """
    Fetch Exoscale [DNS](https://community.exoscale.com/product/networking/dns/) Domains data.

    Corresponding resource: exoscale_domain.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_exoscale as exoscale

    my_domain = exoscale.get_domain(name="my.domain")
    pulumi.export("myDomainId", my_domain.id)
    ```

    Please refer to the examples
    directory for complete configuration examples.


    :param _builtins.str name: The DNS domain name to match.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('exoscale:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult)
    return __ret__.apply(lambda __response__: GetDomainResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ElasticIpArgs', 'ElasticIp']

@pulumi.input_type
class ElasticIpArgs:
    def __init__(__self__, *,
                 zone: pulumi.Input[_builtins.str],
                 address_family: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 healthcheck: Optional[pulumi.Input['ElasticIpHealthcheckArgs']] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 reverse_dns: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ElasticIp resource.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        :param pulumi.Input[_builtins.str] address_family: ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        :param pulumi.Input[_builtins.str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input['ElasticIpHealthcheckArgs'] healthcheck: Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: A map of key/value labels.
        :param pulumi.Input[_builtins.str] reverse_dns: Domain name for reverse DNS record.
        """
        pulumi.set(__self__, "zone", zone)
        if address_family is not None:
            pulumi.set(__self__, "address_family", address_family)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if healthcheck is not None:
            pulumi.set(__self__, "healthcheck", healthcheck)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if reverse_dns is not None:
            pulumi.set(__self__, "reverse_dns", reverse_dns)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Input[_builtins.str]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "zone", value)

    @_builtins.property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        """
        return pulumi.get(self, "address_family")

    @address_family.setter
    def address_family(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address_family", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def healthcheck(self) -> Optional[pulumi.Input['ElasticIpHealthcheckArgs']]:
        """
        Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        """
        return pulumi.get(self, "healthcheck")

    @healthcheck.setter
    def healthcheck(self, value: Optional[pulumi.Input['ElasticIpHealthcheckArgs']]):
        pulumi.set(self, "healthcheck", value)

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of key/value labels.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "labels", value)

    @_builtins.property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Domain name for reverse DNS record.
        """
        return pulumi.get(self, "reverse_dns")

    @reverse_dns.setter
    def reverse_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse_dns", value)


@pulumi.input_type
class _ElasticIpState:
    def __init__(__self__, *,
                 address_family: Optional[pulumi.Input[_builtins.str]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 healthcheck: Optional[pulumi.Input['ElasticIpHealthcheckArgs']] = None,
                 ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 reverse_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ElasticIp resources.
        :param pulumi.Input[_builtins.str] address_family: ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        :param pulumi.Input[_builtins.str] cidr: The Elastic IP (EIP) CIDR.
        :param pulumi.Input[_builtins.str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input['ElasticIpHealthcheckArgs'] healthcheck: Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        :param pulumi.Input[_builtins.str] ip_address: The Elastic IP (EIP) IPv4 or IPv6 address.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: A map of key/value labels.
        :param pulumi.Input[_builtins.str] reverse_dns: Domain name for reverse DNS record.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        if address_family is not None:
            pulumi.set(__self__, "address_family", address_family)
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if healthcheck is not None:
            pulumi.set(__self__, "healthcheck", healthcheck)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if reverse_dns is not None:
            pulumi.set(__self__, "reverse_dns", reverse_dns)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        """
        return pulumi.get(self, "address_family")

    @address_family.setter
    def address_family(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address_family", value)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Elastic IP (EIP) CIDR.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def healthcheck(self) -> Optional[pulumi.Input['ElasticIpHealthcheckArgs']]:
        """
        Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        """
        return pulumi.get(self, "healthcheck")

    @healthcheck.setter
    def healthcheck(self, value: Optional[pulumi.Input['ElasticIpHealthcheckArgs']]):
        pulumi.set(self, "healthcheck", value)

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Elastic IP (EIP) IPv4 or IPv6 address.
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of key/value labels.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "labels", value)

    @_builtins.property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Domain name for reverse DNS record.
        """
        return pulumi.get(self, "reverse_dns")

    @reverse_dns.setter
    def reverse_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse_dns", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("exoscale:index/elasticIp:ElasticIp")
class ElasticIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_family: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 healthcheck: Optional[pulumi.Input[Union['ElasticIpHealthcheckArgs', 'ElasticIpHealthcheckArgsDict']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 reverse_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manage Exoscale [Elastic IPs (EIP)](https://community.exoscale.com/product/networking/eip/).

        Corresponding data source: exoscale_elastic_ip.

        ## Example Usage

        *Unmanaged* EIPv4:

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_elastic_ip = exoscale.ElasticIp("my_elastic_ip", zone="ch-gva-2")
        ```

        *Managed* EIPv6:

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_managed_elastic_ip = exoscale.ElasticIp("my_managed_elastic_ip",
            zone="ch-gva-2",
            address_family="inet6",
            reverse_dns="example.net",
            healthcheck={
                "mode": "https",
                "port": 443,
                "uri": "/health",
                "interval": 5,
                "timeout": 3,
                "strikes_ok": 2,
                "strikes_fail": 3,
                "tls_sni": "example.net",
            })
        ```

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing Elastic IP (EIP) may be imported by `<ID>@<zone>`:

        ```sh
        $ pulumi import exoscale:index/elasticIp:ElasticIp \\ 
        ```

          exoscale_elastic_ip.my_elastic_ip \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6@ch-gva-2

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address_family: ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        :param pulumi.Input[_builtins.str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[Union['ElasticIpHealthcheckArgs', 'ElasticIpHealthcheckArgsDict']] healthcheck: Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: A map of key/value labels.
        :param pulumi.Input[_builtins.str] reverse_dns: Domain name for reverse DNS record.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ElasticIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage Exoscale [Elastic IPs (EIP)](https://community.exoscale.com/product/networking/eip/).

        Corresponding data source: exoscale_elastic_ip.

        ## Example Usage

        *Unmanaged* EIPv4:

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_elastic_ip = exoscale.ElasticIp("my_elastic_ip", zone="ch-gva-2")
        ```

        *Managed* EIPv6:

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_managed_elastic_ip = exoscale.ElasticIp("my_managed_elastic_ip",
            zone="ch-gva-2",
            address_family="inet6",
            reverse_dns="example.net",
            healthcheck={
                "mode": "https",
                "port": 443,
                "uri": "/health",
                "interval": 5,
                "timeout": 3,
                "strikes_ok": 2,
                "strikes_fail": 3,
                "tls_sni": "example.net",
            })
        ```

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing Elastic IP (EIP) may be imported by `<ID>@<zone>`:

        ```sh
        $ pulumi import exoscale:index/elasticIp:ElasticIp \\ 
        ```

          exoscale_elastic_ip.my_elastic_ip \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6@ch-gva-2

        :param str resource_name: The name of the resource.
        :param ElasticIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ElasticIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_family: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 healthcheck: Optional[pulumi.Input[Union['ElasticIpHealthcheckArgs', 'ElasticIpHealthcheckArgsDict']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 reverse_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ElasticIpArgs.__new__(ElasticIpArgs)

            __props__.__dict__["address_family"] = address_family
            __props__.__dict__["description"] = description
            __props__.__dict__["healthcheck"] = healthcheck
            __props__.__dict__["labels"] = labels
            __props__.__dict__["reverse_dns"] = reverse_dns
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
            __props__.__dict__["cidr"] = None
            __props__.__dict__["ip_address"] = None
        super(ElasticIp, __self__).__init__(
            'exoscale:index/elasticIp:ElasticIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address_family: Optional[pulumi.Input[_builtins.str]] = None,
            cidr: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            healthcheck: Optional[pulumi.Input[Union['ElasticIpHealthcheckArgs', 'ElasticIpHealthcheckArgsDict']]] = None,
            ip_address: Optional[pulumi.Input[_builtins.str]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            reverse_dns: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'ElasticIp':
        """
        Get an existing ElasticIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address_family: ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        :param pulumi.Input[_builtins.str] cidr: The Elastic IP (EIP) CIDR.
        :param pulumi.Input[_builtins.str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[Union['ElasticIpHealthcheckArgs', 'ElasticIpHealthcheckArgsDict']] healthcheck: Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        :param pulumi.Input[_builtins.str] ip_address: The Elastic IP (EIP) IPv4 or IPv6 address.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: A map of key/value labels.
        :param pulumi.Input[_builtins.str] reverse_dns: Domain name for reverse DNS record.
        :param pulumi.Input[_builtins.str] zone: ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ElasticIpState.__new__(_ElasticIpState)

        __props__.__dict__["address_family"] = address_family
        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["description"] = description
        __props__.__dict__["healthcheck"] = healthcheck
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["labels"] = labels
        __props__.__dict__["reverse_dns"] = reverse_dns
        __props__.__dict__["zone"] = zone
        return ElasticIp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="addressFamily")
    def address_family(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The Elastic IP (EIP) address family (`inet4` or `inet6`; default: `inet4`).
        """
        return pulumi.get(self, "address_family")

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The Elastic IP (EIP) CIDR.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def healthcheck(self) -> pulumi.Output['outputs.ElasticIpHealthcheck']:
        """
        Healthcheck configuration for *managed* EIPs. It can not be added to an existing *Unmanaged* EIP.
        """
        return pulumi.get(self, "healthcheck")

    @_builtins.property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[_builtins.str]:
        """
        The Elastic IP (EIP) IPv4 or IPv6 address.
        """
        return pulumi.get(self, "ip_address")

    @_builtins.property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A map of key/value labels.
        """
        return pulumi.get(self, "labels")

    @_builtins.property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Domain name for reverse DNS record.
        """
        return pulumi.get(self, "reverse_dns")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AntiAffinityGroupArgs', 'AntiAffinityGroup']

@pulumi.input_type
class AntiAffinityGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AntiAffinityGroup resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[_builtins.str] name: ❗ The anti-affinity group name.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The anti-affinity group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AntiAffinityGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AntiAffinityGroup resources.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[_builtins.str] name: ❗ The anti-affinity group name.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The anti-affinity group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("exoscale:index/antiAffinityGroup:AntiAffinityGroup")
class AntiAffinityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manage Exoscale [Anti-Affinity Groups](https://community.exoscale.com/product/compute/instances/how-to/anti-affinity/).

        Corresponding data source: exoscale_anti_affinity_group.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_anti_affinity_group = exoscale.AntiAffinityGroup("my_anti_affinity_group",
            name="my-anti-affinity-group",
            description="Prevent compute instances to run on the same host")
        ```

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing anti-affinity group may be imported by `<ID>`:

        ```sh
        $ pulumi import exoscale:index/antiAffinityGroup:AntiAffinityGroup \\ 
        ```

          exoscale_anti_affinity_group.my_anti_affinity_group \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[_builtins.str] name: ❗ The anti-affinity group name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AntiAffinityGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage Exoscale [Anti-Affinity Groups](https://community.exoscale.com/product/compute/instances/how-to/anti-affinity/).

        Corresponding data source: exoscale_anti_affinity_group.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_anti_affinity_group = exoscale.AntiAffinityGroup("my_anti_affinity_group",
            name="my-anti-affinity-group",
            description="Prevent compute instances to run on the same host")
        ```

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing anti-affinity group may be imported by `<ID>`:

        ```sh
        $ pulumi import exoscale:index/antiAffinityGroup:AntiAffinityGroup \\ 
        ```

          exoscale_anti_affinity_group.my_anti_affinity_group \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param AntiAffinityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AntiAffinityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AntiAffinityGroupArgs.__new__(AntiAffinityGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
        super(AntiAffinityGroup, __self__).__init__(
            'exoscale:index/antiAffinityGroup:AntiAffinityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'AntiAffinityGroup':
        """
        Get an existing AntiAffinityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[_builtins.str] name: ❗ The anti-affinity group name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AntiAffinityGroupState.__new__(_AntiAffinityGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        return AntiAffinityGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The anti-affinity group name.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IamApiKeyArgs', 'IamApiKey']

@pulumi.input_type
class IamApiKeyArgs:
    def __init__(__self__, *,
                 role_id: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['IamApiKeyTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a IamApiKey resource.
        :param pulumi.Input[_builtins.str] role_id: ❗ IAM API role ID.
        :param pulumi.Input[_builtins.str] name: ❗ IAM API Key name.
        """
        pulumi.set(__self__, "role_id", role_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[_builtins.str]:
        """
        ❗ IAM API role ID.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ IAM API Key name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['IamApiKeyTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['IamApiKeyTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _IamApiKeyState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['IamApiKeyTimeoutsArgs']] = None):
        """
        Input properties used for looking up and filtering IamApiKey resources.
        :param pulumi.Input[_builtins.str] key: The IAM API Key to match.
        :param pulumi.Input[_builtins.str] name: ❗ IAM API Key name.
        :param pulumi.Input[_builtins.str] role_id: ❗ IAM API role ID.
        :param pulumi.Input[_builtins.str] secret: Secret for the IAM API Key.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IAM API Key to match.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ IAM API Key name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ IAM API role ID.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_id", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret for the IAM API Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['IamApiKeyTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['IamApiKeyTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.type_token("exoscale:index/iamApiKey:IamApiKey")
class IamApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['IamApiKeyTimeoutsArgs', 'IamApiKeyTimeoutsArgsDict']]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_role = exoscale.IamRole("my_role",
            name="my-role",
            description="Example role",
            editable=True,
            policy={
                "default_service_strategy": "deny",
                "services": {
                    "sos": {
                        "type": "allow",
                    },
                },
            })
        my_api_key = exoscale.IamApiKey("my_api_key",
            name="my-api-key",
            role_id=my_role.id)
        ```

        Please refer to the examples
        directory for complete configuration examples.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: ❗ IAM API Key name.
        :param pulumi.Input[_builtins.str] role_id: ❗ IAM API role ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IamApiKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_role = exoscale.IamRole("my_role",
            name="my-role",
            description="Example role",
            editable=True,
            policy={
                "default_service_strategy": "deny",
                "services": {
                    "sos": {
                        "type": "allow",
                    },
                },
            })
        my_api_key = exoscale.IamApiKey("my_api_key",
            name="my-api-key",
            role_id=my_role.id)
        ```

        Please refer to the examples
        directory for complete configuration examples.

        :param str resource_name: The name of the resource.
        :param IamApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['IamApiKeyTimeoutsArgs', 'IamApiKeyTimeoutsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamApiKeyArgs.__new__(IamApiKeyArgs)

            __props__.__dict__["name"] = name
            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["key"] = None
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IamApiKey, __self__).__init__(
            'exoscale:index/iamApiKey:IamApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            role_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['IamApiKeyTimeoutsArgs', 'IamApiKeyTimeoutsArgsDict']]] = None) -> 'IamApiKey':
        """
        Get an existing IamApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] key: The IAM API Key to match.
        :param pulumi.Input[_builtins.str] name: ❗ IAM API Key name.
        :param pulumi.Input[_builtins.str] role_id: ❗ IAM API role ID.
        :param pulumi.Input[_builtins.str] secret: Secret for the IAM API Key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IamApiKeyState.__new__(_IamApiKeyState)

        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["secret"] = secret
        __props__.__dict__["timeouts"] = timeouts
        return IamApiKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        The IAM API Key to match.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ IAM API Key name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ IAM API role ID.
        """
        return pulumi.get(self, "role_id")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[_builtins.str]:
        """
        Secret for the IAM API Key.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.IamApiKeyTimeouts']]:
        return pulumi.get(self, "timeouts")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SecurityGroupArgs', 'SecurityGroup']

@pulumi.input_type
class SecurityGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SecurityGroup resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] external_sources: A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        :param pulumi.Input[_builtins.str] name: ❗ The security group name.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_sources is not None:
            pulumi.set(__self__, "external_sources", external_sources)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalSources")
    def external_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        """
        return pulumi.get(self, "external_sources")

    @external_sources.setter
    def external_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "external_sources", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The security group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SecurityGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SecurityGroup resources.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] external_sources: A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        :param pulumi.Input[_builtins.str] name: ❗ The security group name.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_sources is not None:
            pulumi.set(__self__, "external_sources", external_sources)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalSources")
    def external_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        """
        return pulumi.get(self, "external_sources")

    @external_sources.setter
    def external_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "external_sources", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ❗ The security group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("exoscale:index/securityGroup:SecurityGroup")
class SecurityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manage Exoscale [Security Groups](https://community.exoscale.com/product/networking/security-group/).

        Corresponding data source: exoscale_security_group.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_security_group = exoscale.SecurityGroup("my_security_group", name="my-security-group")
        ```

        Next step is to attach exoscale_security_group_rule(s) to the group.

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing security group may be imported by `<ID>`:

        ```sh
        $ pulumi import exoscale:index/securityGroup:SecurityGroup \\ 
        ```

          exoscale_security_group.my_security_group \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] external_sources: A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        :param pulumi.Input[_builtins.str] name: ❗ The security group name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecurityGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage Exoscale [Security Groups](https://community.exoscale.com/product/networking/security-group/).

        Corresponding data source: exoscale_security_group.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_exoscale as exoscale

        my_security_group = exoscale.SecurityGroup("my_security_group", name="my-security-group")
        ```

        Next step is to attach exoscale_security_group_rule(s) to the group.

        Please refer to the examples
        directory for complete configuration examples.

        ## Import

        An existing security group may be imported by `<ID>`:

        ```sh
        $ pulumi import exoscale:index/securityGroup:SecurityGroup \\ 
        ```

          exoscale_security_group.my_security_group \\

          f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param SecurityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGroupArgs.__new__(SecurityGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["external_sources"] = external_sources
            __props__.__dict__["name"] = name
        super(SecurityGroup, __self__).__init__(
            'exoscale:index/securityGroup:SecurityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            external_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'SecurityGroup':
        """
        Get an existing SecurityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: ❗ A free-form text describing the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] external_sources: A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        :param pulumi.Input[_builtins.str] name: ❗ The security group name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGroupState.__new__(_SecurityGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["external_sources"] = external_sources
        __props__.__dict__["name"] = name
        return SecurityGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ❗ A free-form text describing the group.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externalSources")
    def external_sources(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of external network sources, in [CIDR](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation) notation.
        """
        return pulumi.get(self, "external_sources")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        ❗ The security group name.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetComputeInstanceListResult',
    'AwaitableGetComputeInstanceListResult',
    'get_compute_instance_list',
    'get_compute_instance_list_output',
]

@pulumi.output_type
class GetComputeInstanceListResult:
    """
    A collection of values returned by getComputeInstanceList.
    """
    def __init__(__self__, created_at=None, deploy_target_id=None, disk_size=None, enable_secure_boot=None, enable_tpm=None, id=None, instances=None, ipv6=None, ipv6_address=None, labels=None, manager_id=None, manager_type=None, name=None, public_ip_address=None, reverse_dns=None, ssh_key=None, state=None, template_id=None, type=None, user_data=None, zone=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if deploy_target_id and not isinstance(deploy_target_id, str):
            raise TypeError("Expected argument 'deploy_target_id' to be a str")
        pulumi.set(__self__, "deploy_target_id", deploy_target_id)
        if disk_size and not isinstance(disk_size, int):
            raise TypeError("Expected argument 'disk_size' to be a int")
        pulumi.set(__self__, "disk_size", disk_size)
        if enable_secure_boot and not isinstance(enable_secure_boot, bool):
            raise TypeError("Expected argument 'enable_secure_boot' to be a bool")
        pulumi.set(__self__, "enable_secure_boot", enable_secure_boot)
        if enable_tpm and not isinstance(enable_tpm, bool):
            raise TypeError("Expected argument 'enable_tpm' to be a bool")
        pulumi.set(__self__, "enable_tpm", enable_tpm)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if ipv6 and not isinstance(ipv6, bool):
            raise TypeError("Expected argument 'ipv6' to be a bool")
        pulumi.set(__self__, "ipv6", ipv6)
        if ipv6_address and not isinstance(ipv6_address, str):
            raise TypeError("Expected argument 'ipv6_address' to be a str")
        pulumi.set(__self__, "ipv6_address", ipv6_address)
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        pulumi.set(__self__, "labels", labels)
        if manager_id and not isinstance(manager_id, str):
            raise TypeError("Expected argument 'manager_id' to be a str")
        pulumi.set(__self__, "manager_id", manager_id)
        if manager_type and not isinstance(manager_type, str):
            raise TypeError("Expected argument 'manager_type' to be a str")
        pulumi.set(__self__, "manager_type", manager_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if public_ip_address and not isinstance(public_ip_address, str):
            raise TypeError("Expected argument 'public_ip_address' to be a str")
        pulumi.set(__self__, "public_ip_address", public_ip_address)
        if reverse_dns and not isinstance(reverse_dns, str):
            raise TypeError("Expected argument 'reverse_dns' to be a str")
        pulumi.set(__self__, "reverse_dns", reverse_dns)
        if ssh_key and not isinstance(ssh_key, str):
            raise TypeError("Expected argument 'ssh_key' to be a str")
        pulumi.set(__self__, "ssh_key", ssh_key)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if template_id and not isinstance(template_id, str):
            raise TypeError("Expected argument 'template_id' to be a str")
        pulumi.set(__self__, "template_id", template_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if user_data and not isinstance(user_data, str):
            raise TypeError("Expected argument 'user_data' to be a str")
        pulumi.set(__self__, "user_data", user_data)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="deployTargetId")
    def deploy_target_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "deploy_target_id")

    @_builtins.property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[_builtins.int]:
        """
        Match against this int
        """
        return pulumi.get(self, "disk_size")

    @_builtins.property
    @pulumi.getter(name="enableSecureBoot")
    def enable_secure_boot(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "enable_secure_boot")

    @_builtins.property
    @pulumi.getter(name="enableTpm")
    def enable_tpm(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "enable_tpm")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetComputeInstanceListInstanceResult']:
        """
        The list of exoscale*compute*instance.
        """
        return pulumi.get(self, "instances")

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> Optional[_builtins.bool]:
        """
        Match against this bool
        """
        return pulumi.get(self, "ipv6")

    @_builtins.property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "ipv6_address")

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
        """
        return pulumi.get(self, "labels")

    @_builtins.property
    @pulumi.getter(name="managerId")
    def manager_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "manager_id")

    @_builtins.property
    @pulumi.getter(name="managerType")
    def manager_type(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "manager_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="publicIpAddress")
    def public_ip_address(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "public_ip_address")

    @_builtins.property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "reverse_dns")

    @_builtins.property
    @pulumi.getter(name="sshKey")
    def ssh_key(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "ssh_key")

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="templateId")
    def template_id(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "template_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[_builtins.str]:
        """
        Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
        """
        return pulumi.get(self, "user_data")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        """
        The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
        """
        return pulumi.get(self, "zone")


class AwaitableGetComputeInstanceListResult(GetComputeInstanceListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetComputeInstanceListResult(
            created_at=self.created_at,
            deploy_target_id=self.deploy_target_id,
            disk_size=self.disk_size,
            enable_secure_boot=self.enable_secure_boot,
            enable_tpm=self.enable_tpm,
            id=self.id,
            instances=self.instances,
            ipv6=self.ipv6,
            ipv6_address=self.ipv6_address,
            labels=self.labels,
            manager_id=self.manager_id,
            manager_type=self.manager_type,
            name=self.name,
            public_ip_address=self.public_ip_address,
            reverse_dns=self.reverse_dns,
            ssh_key=self.ssh_key,
            state=self.state,
            template_id=self.template_id,
            type=self.type,
            user_data=self.user_data,
            zone=self.zone)


def get_compute_instance_list(created_at: Optional[_builtins.str] = None,
                              deploy_target_id: Optional[_builtins.str] = None,
                              disk_size: Optional[_builtins.int] = None,
                              enable_secure_boot: Optional[_builtins.bool] = None,
                              enable_tpm: Optional[_builtins.bool] = None,
                              id: Optional[_builtins.str] = None,
                              ipv6: Optional[_builtins.bool] = None,
                              ipv6_address: Optional[_builtins.str] = None,
                              labels: Optional[Mapping[str, _builtins.str]] = None,
                              manager_id: Optional[_builtins.str] = None,
                              manager_type: Optional[_builtins.str] = None,
                              name: Optional[_builtins.str] = None,
                              public_ip_address: Optional[_builtins.str] = None,
                              reverse_dns: Optional[_builtins.str] = None,
                              ssh_key: Optional[_builtins.str] = None,
                              state: Optional[_builtins.str] = None,
                              template_id: Optional[_builtins.str] = None,
                              type: Optional[_builtins.str] = None,
                              user_data: Optional[_builtins.str] = None,
                              zone: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetComputeInstanceListResult:
    """
    List Exoscale [Compute Instances](https://community.exoscale.com/documentation/compute/).

    Corresponding resource: exoscale_compute_instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_exoscale as exoscale
    import pulumi_std as std

    my_compute_instance_list = exoscale.get_compute_instance_list(zone="ch-gva-2",
        type="standard.micro",
        name="/.*ubuntu.*/",
        labels={
            "customer": "/.*bank.*/",
            "contract": "premium-support",
        })
    pulumi.export("myComputeInstanceIds", std.join(separator="\\n",
        input=std.formatlist(input="%s",
            args=[[__item.id for __item in my_compute_instance_list.instances]]).result).result)
    ```

    Please refer to the examples
    directory for complete configuration examples.


    :param _builtins.str created_at: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str deploy_target_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int disk_size: Match against this int
    :param _builtins.str id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool ipv6: Match against this bool
    :param _builtins.str ipv6_address: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param Mapping[str, _builtins.str] labels: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str manager_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str manager_type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str name: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str public_ip_address: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str reverse_dns: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str ssh_key: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str state: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str template_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str user_data: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str zone: The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
    """
    __args__ = dict()
    __args__['createdAt'] = created_at
    __args__['deployTargetId'] = deploy_target_id
    __args__['diskSize'] = disk_size
    __args__['enableSecureBoot'] = enable_secure_boot
    __args__['enableTpm'] = enable_tpm
    __args__['id'] = id
    __args__['ipv6'] = ipv6
    __args__['ipv6Address'] = ipv6_address
    __args__['labels'] = labels
    __args__['managerId'] = manager_id
    __args__['managerType'] = manager_type
    __args__['name'] = name
    __args__['publicIpAddress'] = public_ip_address
    __args__['reverseDns'] = reverse_dns
    __args__['sshKey'] = ssh_key
    __args__['state'] = state
    __args__['templateId'] = template_id
    __args__['type'] = type
    __args__['userData'] = user_data
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('exoscale:index/getComputeInstanceList:getComputeInstanceList', __args__, opts=opts, typ=GetComputeInstanceListResult).value

    return AwaitableGetComputeInstanceListResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        deploy_target_id=pulumi.get(__ret__, 'deploy_target_id'),
        disk_size=pulumi.get(__ret__, 'disk_size'),
        enable_secure_boot=pulumi.get(__ret__, 'enable_secure_boot'),
        enable_tpm=pulumi.get(__ret__, 'enable_tpm'),
        id=pulumi.get(__ret__, 'id'),
        instances=pulumi.get(__ret__, 'instances'),
        ipv6=pulumi.get(__ret__, 'ipv6'),
        ipv6_address=pulumi.get(__ret__, 'ipv6_address'),
        labels=pulumi.get(__ret__, 'labels'),
        manager_id=pulumi.get(__ret__, 'manager_id'),
        manager_type=pulumi.get(__ret__, 'manager_type'),
        name=pulumi.get(__ret__, 'name'),
        public_ip_address=pulumi.get(__ret__, 'public_ip_address'),
        reverse_dns=pulumi.get(__ret__, 'reverse_dns'),
        ssh_key=pulumi.get(__ret__, 'ssh_key'),
        state=pulumi.get(__ret__, 'state'),
        template_id=pulumi.get(__ret__, 'template_id'),
        type=pulumi.get(__ret__, 'type'),
        user_data=pulumi.get(__ret__, 'user_data'),
        zone=pulumi.get(__ret__, 'zone'))
def get_compute_instance_list_output(created_at: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     deploy_target_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     disk_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                     enable_secure_boot: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                     enable_tpm: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                     id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     ipv6: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                     ipv6_address: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     labels: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                     manager_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     manager_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     public_ip_address: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     reverse_dns: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     ssh_key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     state: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     template_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     user_data: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     zone: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetComputeInstanceListResult]:
    """
    List Exoscale [Compute Instances](https://community.exoscale.com/documentation/compute/).

    Corresponding resource: exoscale_compute_instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_exoscale as exoscale
    import pulumi_std as std

    my_compute_instance_list = exoscale.get_compute_instance_list(zone="ch-gva-2",
        type="standard.micro",
        name="/.*ubuntu.*/",
        labels={
            "customer": "/.*bank.*/",
            "contract": "premium-support",
        })
    pulumi.export("myComputeInstanceIds", std.join(separator="\\n",
        input=std.formatlist(input="%s",
            args=[[__item.id for __item in my_compute_instance_list.instances]]).result).result)
    ```

    Please refer to the examples
    directory for complete configuration examples.


    :param _builtins.str created_at: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str deploy_target_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.int disk_size: Match against this int
    :param _builtins.str id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.bool ipv6: Match against this bool
    :param _builtins.str ipv6_address: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param Mapping[str, _builtins.str] labels: Match against key/values. Keys are matched exactly, while values may be matched as a regex if you supply a string that begins and ends with "/"
    :param _builtins.str manager_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str manager_type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str name: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str public_ip_address: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str reverse_dns: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str ssh_key: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str state: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str template_id: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str type: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str user_data: Match against this string. If you supply a string that begins and ends with a "/" it will be matched as a regex.
    :param _builtins.str zone: The Exoscale [Zone](https://www.exoscale.com/datacenters/) name.
    """
    __args__ = dict()
    __args__['createdAt'] = created_at
    __args__['deployTargetId'] = deploy_target_id
    __args__['diskSize'] = disk_size
    __args__['enableSecureBoot'] = enable_secure_boot
    __args__['enableTpm'] = enable_tpm
    __args__['id'] = id
    __args__['ipv6'] = ipv6
    __args__['ipv6Address'] = ipv6_address
    __args__['labels'] = labels
    __args__['managerId'] = manager_id
    __args__['managerType'] = manager_type
    __args__['name'] = name
    __args__['publicIpAddress'] = public_ip_address
    __args__['reverseDns'] = reverse_dns
    __args__['sshKey'] = ssh_key
    __args__['state'] = state
    __args__['templateId'] = template_id
    __args__['type'] = type
    __args__['userData'] = user_data
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('exoscale:index/getComputeInstanceList:getComputeInstanceList', __args__, opts=opts, typ=GetComputeInstanceListResult)
    return __ret__.apply(lambda __response__: GetComputeInstanceListResult(
        created_at=pulumi.get(__response__, 'created_at'),
        deploy_target_id=pulumi.get(__response__, 'deploy_target_id'),
        disk_size=pulumi.get(__response__, 'disk_size'),
        enable_secure_boot=pulumi.get(__response__, 'enable_secure_boot'),
        enable_tpm=pulumi.get(__response__, 'enable_tpm'),
        id=pulumi.get(__response__, 'id'),
        instances=pulumi.get(__response__, 'instances'),
        ipv6=pulumi.get(__response__, 'ipv6'),
        ipv6_address=pulumi.get(__response__, 'ipv6_address'),
        labels=pulumi.get(__response__, 'labels'),
        manager_id=pulumi.get(__response__, 'manager_id'),
        manager_type=pulumi.get(__response__, 'manager_type'),
        name=pulumi.get(__response__, 'name'),
        public_ip_address=pulumi.get(__response__, 'public_ip_address'),
        reverse_dns=pulumi.get(__response__, 'reverse_dns'),
        ssh_key=pulumi.get(__response__, 'ssh_key'),
        state=pulumi.get(__response__, 'state'),
        template_id=pulumi.get(__response__, 'template_id'),
        type=pulumi.get(__response__, 'type'),
        user_data=pulumi.get(__response__, 'user_data'),
        zone=pulumi.get(__response__, 'zone')))
